# Copyright (C) 2006-2008 Red Hat, Inc.
#
# This program is free software; you can redistribute
# it and/or modify it under the terms of version 2 of the
# GNU General Public License as published by the
# Free Software Foundation.

from ricci_defines import MAPPER_ATARAID_TYPE, MAPPER_CRYPTO_TYPE, \
	MAPPER_iSCSI_TYPE, MAPPER_MDRAID_TYPE, MAPPER_MULTIPATH_TYPE, \
	MAPPER_PT_TYPE, MAPPER_SYS_TYPE, MAPPER_VG_TYPE

## request vars ##

PAGETYPE		= 'pagetype'
CLUNAME			= 'clustername'
STONAME			= 'storagename'

PT_MAPPER_ID	= 'mapper_id'
PT_MAPPER_TYPE	= 'mapper_type'
PT_PATH			= 'bd_path'

STORAGE_COMMIT_CHANGES = 'commit_changes'

# storage pagetypes #
STORAGESYS		= '0'
STORAGE_CONFIG	= '43'
STORAGE			= '44'
CLUSTER_STORAGE	= '45'
VIEW_MAPPERS	= '51'
VIEW_MAPPER		= '52'
VIEW_BDS		= '61'
VIEW_BD			= '62'
CREATE_MAPPER	= '101'
ADD_SOURCES		= '102'

# mapper pretty names
PRETTY_MAPPER_INFO = {
	MAPPER_SYS_TYPE:
		( 'Hard Drives',		'Hard Drive',		'BUG: source not defined' ),
	MAPPER_VG_TYPE:
		( 'Volume Group',		'Logical Volume',	'Physical Volume' ),
	MAPPER_PT_TYPE:
		( 'Partition Table',	'Partition',		'Disk' ),
	MAPPER_MDRAID_TYPE:
		( 'Software RAID',		'Volume',			'Disk' ),
	MAPPER_ATARAID_TYPE:
		( 'ATA-RAID',			'Volume',			'Disk' ),
	MAPPER_MULTIPATH_TYPE:
		( 'Multipath',			'Multipath',		'Path' ),
	MAPPER_CRYPTO_TYPE:
		( 'Encryption',			'Volume',			'Device' ),
	MAPPER_iSCSI_TYPE:
		( 'iSCSI',				'Volume',			'BUG: source not defined' )
}

def get_pretty_mapper_info(mapper_type):
	return PRETTY_MAPPER_INFO.get(mapper_type) or \
		(	'Mapper %s' % mapper_type,
			'%s\s target' % mapper_type,
			'%s\s source' % mapper_type
		)

PRETTY_PROP_NAMES = {
	'active':					'Active',
	'attrs':					'Attributes',
	'bd':						'Block Device',
	'block_count':				'Number of Blocks',
	'block_size':				'Block Size',
	'bootable':					'Bootable',
	'cluster_name':				'Cluster Name',
	'clustered':				'Clustered',
	'dir_index':				'Use Hashed Binary Trees',
	'disklabel':				'Partition Table Type',
	'extents_free':				'Free Extents',
	'extent_size':				'Extent Size',
	'extents_total':			'Total Extents',
	'extents_used':				'Used Extents',
	'failed':					'Failed',
	'format':					'Format',
	'fstab':					'List in /etc/fstab',
	'fstabpoint':				'/etc/fstab Mountpoint',
	'gfs_fsname':				'Unique GFS Name',
	'has_journal':				'Journaling Enabled - ext3, ext4',
	'journals_num':				'Number of Journals',
	'journal_size':				'Journal Size',
	'label':					'Label',
	'level':					'Level',
	'locking_protocol':			'Locking Protocol',
	'lvname':					'Logical Volume Name',
	'max_lvs':					'Maximum Logical Volumes',
	'max_pvs':					'Maximum Physical Volumes',
	'max_sources':				'Maximum Disks',
	'min_sources':				'Minimum Disks',
	'mirrored':					'Mirrored',
	'model':					'Model',
	'mount':					'Mount',
	'mountable':				'Mountable',
	'mountpoint':				'Mountpoint',
	'num_devices':				'Number of Devices',
	'num_spares':				'Number of Spares',
	'partition_begin':			'Partition Begin',
	'partition_num':			'Partition Number',
	'partition_type':			'Partition Type',
	'path':						'Path',
	'raid':						'Raid',
	'raid_level':				'Raid Level',
	'removable':				'Removable',
	'scsi_bus':					'SCSI Address',
	'scsi_id':					'SCSI ID',
	'size':						'Size',
	'size_free':				'Unused',
	'snapshot':					'Snapshot',
	'snapshot_origin':			'Snapshot Origin',
	'snapshots':				'Snapshots',
	'snapshot_usage_percent':	'Snapshot Usage',
	'state':					'State',
	'swapon':					'Active Swap',
	'type':						'Type',
	'uuid':						'UUID',
	'vendor':					'Vendor',
	'vgname':					'Volume Group Name'
}

def get_pretty_prop_name(name):
	return PRETTY_PROP_NAMES.get(name) or name

PRETTY_FS_NAMES = {
	'ext':			'Linux Extended FS',
	'swap':			'Swap',
	'gfs1':			'GFS1 - Global FS v.1',
	'gfs2':			'GFS2 - Global FS v.2',
	'minix':		'Minix FS',
	'ufs':			'Unix Fast FS',
	'xfs':			'SGI XFS',
	'isofs':		'ISO 9660 CD-ROM FS',
	'cramfs':		'Cram FS',
	'reiserfs':		'Reiser FS',
	'jffs':			'Journalled Flash FS v.1',
	'jffs2':		'Journalled Flash FS v.2',
	'squashfs':		'Squash FS',
	'vfat':			'MS vfat FS',
	'msdos':		'MS-DOS FS',
	'affs':			'Amiga FS',
	'befs':			'BeOS FS',
	'bfs':			'SCO UnixWare BFS',
	'jfs':			'Journaled Filesystem (JFS)',
	'efs':			'efs',
	'freevxfs':		'Veritas Filesystem (VxFS)',
	'hfsplus':		'Macintosh extended FS',
	'hfs':			'Macintosh FS',
	'ncpfs':		'ncpfs',
	'ocfs2':		'Oracle Clustered FS v.2',
	'relayfs':		'Relay FS',
	'udf':			'Universal Disk Format'
}

def get_pretty_fs_name(name):
	return PRETTY_FS_NAMES.get(name) or name

# icons
MAPPER_ICONS = {
	MAPPER_SYS_TYPE:
		( '',							'icon_bd_ide.png',			''),
	MAPPER_VG_TYPE:
		( 'icon_mapper_VG.png',			'icon_bd_LV.png',			'icon_content_PV.png'),
	MAPPER_PT_TYPE:
		( 'icon_mapper_PT.png',			'icon_bd_partition.png',	''),
	MAPPER_MDRAID_TYPE:
		( 'icon_mapper_raid.png',		'icon_bd_raid.png',			''),
	MAPPER_ATARAID_TYPE:
		( 'icon_mapper_raid.png',		'icon_bd_raid.png',			''),
	MAPPER_MULTIPATH_TYPE:
		( 'icon_mapper_multipath.png',	'icon_bd_multipath.png',	''),
	MAPPER_CRYPTO_TYPE:
		( 'icon_mapper_crypto.png',		'icon_bd_crypto.png',		''),
	MAPPER_iSCSI_TYPE:
		( '',							'icon_bd_net.png',			'')
}

def get_mapper_icons(mapper_type):
	return MAPPER_ICONS.get(mapper_type) or ('', '', '')

def get_fs_icon(dummy):
	# all fss have the same icon
	return 'icon_content_FS.png'
